@@ -67,6 +67,48 @@ function testDeveloperElementsAreHidden(item: HTMLElement): void {
   testElementsVisibility(item, devElements, false);
 }
 
+/**
+ * Helper to create a runtime error object with default values.
+ */
+function createRuntimeError(
+    extensionId: string,
+    customFields?: Partial<chrome.developerPrivate.RuntimeError>):
+    chrome.developerPrivate.RuntimeError {
+  return {
+    type: chrome.developerPrivate.ErrorType.RUNTIME,
+    extensionId: extensionId,
+    fromIncognito: false,
+    source: '',
+    message: 'Some runtime error',
+    id: 1,
+    severity: chrome.developerPrivate.ErrorLevel.ERROR,
+    contextUrl: '',
+    occurrences: 1,
+    renderViewId: 0,
+    renderProcessId: 0,
+    canInspect: false,
+    stackTrace: [],
+    isServiceWorker: false,
+    ...customFields,
+  };
+}
+
+/**
+ * Helper to check if errors button exists and what type it is.
+ */
+function getErrorsButtonInfo(item: HTMLElement):
+    {exists: boolean, isWarning: boolean, isError: boolean} {
+  const btn = item.shadowRoot!.querySelector('#errors-button');
+  if (!btn) {
+    return {exists: false, isWarning: false, isError: false};
+  }
+  return {
+    exists: true,
+    isWarning: btn.classList.contains('warning'),
+    isError: btn.classList.contains('error'),
+  };
+}
+
 suite('ExtensionItemTest', function() {
   /**
    * Extension item created before each test.
@@ -710,4 +752,65 @@ suite('ExtensionItemTest', function() {
         item.shadowRoot.querySelector<HTMLElement>('#account-upload-button')!,
         'uploadItemToAccount', [item.data.id]);
   });
+
+  test('ShowErrorAsWarningsButtonLabel', async () => {
+    // 1. No runtime errors, no install warnings: button should show "Warnings"
+    // label.
+    let data = createExtensionInfo(item.data);
+    data.runtimeErrors = [];
+    data.installWarnings = [];
+    data.manifestErrors = [{
+      type: chrome.developerPrivate.ErrorType.MANIFEST,
+      extensionId: data.id,
+      fromIncognito: false,
+      source: 'manifest.json',
+      message: 'Some manifest error',
+      id: 1,
+      manifestKey: 'background',
+    }];
+    item.data = data;
+    await microtasksFinished();
+    let buttonInfo = getErrorsButtonInfo(item);
+    assertTrue(buttonInfo.exists, 'Errors button should exist');
+    assertTrue(
+        buttonInfo.isWarning,
+        'Button should have warning class when no errors or install warnings');
+
+    // 2. Has runtime errors: button should show "Errors" label.
+    data = createExtensionInfo(item.data);
+    data.runtimeErrors = [createRuntimeError(data.id)];
+    data.installWarnings = [];
+    item.data = data;
+    await microtasksFinished();
+    buttonInfo = getErrorsButtonInfo(item);
+    assertTrue(buttonInfo.exists, 'Errors button should exist');
+    assertTrue(
+        buttonInfo.isError,
+        'Button should have error class when runtime errors exist');
+
+    // 3. Has install warnings: button should show "Errors" label.
+    data = createExtensionInfo(item.data);
+    data.runtimeErrors = [];
+    data.installWarnings = ['Some install warning'];
+    item.data = data;
+    await microtasksFinished();
+    buttonInfo = getErrorsButtonInfo(item);
+    assertTrue(buttonInfo.exists, 'Errors button should exist');
+    assertTrue(
+        buttonInfo.isError,
+        'Button should have error class when install warnings exist');
+
+    // 4. Has both runtime errors and install warnings: button should show
+    // "Errors" label.
+    data = createExtensionInfo(item.data);
+    data.runtimeErrors = [createRuntimeError(data.id, {id: 2})];
+    data.installWarnings = ['Some install warning'];
+    item.data = data;
+    await microtasksFinished();
+    buttonInfo = getErrorsButtonInfo(item);
+    assertTrue(buttonInfo.exists, 'Errors button should exist');
+    assertTrue(
+        buttonInfo.isError,
+        'Button should have error class when both errors and warnings exist');
+  });
 });
