@@ -353,6 +353,50 @@ suite('Basic', function() {
     assertFalse(!!routes.AUTOFILL_AI);
   });
 
+  test('privacySandbox routes defined', function() {
+    // Case 1
+    loadTimeData.overrideValues({
+      isPrivacySandboxRestricted: true,
+      isPrivacySandboxRestrictedNoticeEnabled: false,
+    });
+    resetPageVisibilityForTesting();
+    resetRouterForTesting();
+
+    assertFalse(!!routes.PRIVACY_SANDBOX);
+    assertFalse(!!routes.PRIVACY_SANDBOX_TOPICS);
+    assertFalse(!!routes.PRIVACY_SANDBOX_MANAGE_TOPICS);
+    assertFalse(!!routes.PRIVACY_SANDBOX_FLEDGE);
+    assertFalse(!!routes.PRIVACY_SANDBOX_AD_MEASUREMENT);
+
+    // Case 2
+    loadTimeData.overrideValues({
+      isPrivacySandboxRestricted: false,
+      isPrivacySandboxRestrictedNoticeEnabled: false,
+    });
+    resetPageVisibilityForTesting();
+    resetRouterForTesting();
+
+    assertTrue(!!routes.PRIVACY_SANDBOX);
+    assertTrue(!!routes.PRIVACY_SANDBOX_TOPICS);
+    assertTrue(!!routes.PRIVACY_SANDBOX_MANAGE_TOPICS);
+    assertTrue(!!routes.PRIVACY_SANDBOX_FLEDGE);
+    assertTrue(!!routes.PRIVACY_SANDBOX_AD_MEASUREMENT);
+
+    // Case 3
+    loadTimeData.overrideValues({
+      isPrivacySandboxRestricted: true,
+      isPrivacySandboxRestrictedNoticeEnabled: true,
+    });
+    resetPageVisibilityForTesting();
+    resetRouterForTesting();
+
+    assertTrue(!!routes.PRIVACY_SANDBOX);
+    assertFalse(!!routes.PRIVACY_SANDBOX_TOPICS);
+    assertFalse(!!routes.PRIVACY_SANDBOX_MANAGE_TOPICS);
+    assertFalse(!!routes.PRIVACY_SANDBOX_FLEDGE);
+    assertTrue(!!routes.PRIVACY_SANDBOX_AD_MEASUREMENT);
+  });
+
   // <if expr="not is_chromeos">
   test('account route existence', function() {
     resetPageVisibilityForTesting({people: true});
